Learn R Programming

bigergm (version 1.2.5)

get_within_networks: Obtain the within-block networks defined by the block attribute.

Description

Function to return a list of networks, each network representing the within-block network of a block.

Usage

get_within_networks(network, block, combined_networks = TRUE)

Value

a list of networks

Arguments

network

a network object

block

a vector of integers representing the block of each node

combined_networks

a boolean indicating whether the between-block networks should be returned as a combined_networks object or not (default is TRUE)

Examples

Run this code
# Load an embedded network object.
data(toyNet)
get_within_networks(toyNet, toyNet %v% "block")

Run the code above in your browser using DataLab