- object
An bigergm object.
- ...
Additional arguments, to be passed to simulate_bigergm,
which, in turn, passes the information to simulate_formula.
See documentation for bigergm.
- type
the type of evaluation to perform. Can take the values full or within. full performs the evaluation on all edges, and within only considers within-block edges.
- control_within
MCMC parameters as an instance of control.simulate.formula to be used for the within-block simulations.
- seed
the seed to be passed to simulate_bigergm. If NULL, a random seed is used.
- nsim
the number of simulations to employ for calculating goodness of fit, default is 100.
- compute_geodesic_distance
if TRUE, the distribution of geodesic distances is also computed (considerably increases computation time on large networks. FALSE by default.)
- start_from_observed
if TRUE, MCMC uses the observed network as a starting point. If FALSE, MCMC starts from a random network.
- simulate_sbm
if TRUE, the between-block connections are simulated from the estimated stochastic block model from the first stage not the estimated ERGM.