Learn R Programming

bigergm (version 1.2.5)

get_between_networks: Obtain the between-block networks defined by the block attribute.

Description

Function to return a list of networks, each network representing the within-block network of a block.

Usage

get_between_networks(network, block)

Value

a list of networks

Arguments

network

a network object

block

a vector of integers representing the block of each node

Examples

Run this code
# Load an embedded network object.
data(toyNet)
get_within_networks(toyNet, toyNet %v% "block")

Run the code above in your browser using DataLab