powered by
Function to return a list of networks, each network representing the within-block network of a block.
get_between_networks(network, block)
a list of networks
a network object
a vector of integers representing the block of each node
# Load an embedded network object. data(toyNet) get_within_networks(toyNet, toyNet %v% "block")
Run the code above in your browser using DataLab