powered by
Function to return a list of networks, each network representing the within-block network of a block.
get_within_networks(network, block, combined_networks = TRUE)
a list of networks
a network object
a vector of integers representing the block of each node
a boolean indicating whether the between-block networks should be returned as a combined_networks object or not (default is TRUE)
combined_networks
# Load an embedded network object. data(toyNet) get_within_networks(toyNet, toyNet %v% "block")
Run the code above in your browser using DataLab